Class: Google::Apis::TrafficdirectorV3::UpdateFailureState
- Inherits:
-
Object
- Object
- Google::Apis::TrafficdirectorV3::UpdateFailureState
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/trafficdirector_v3/classes.rb,
lib/google/apis/trafficdirector_v3/representations.rb,
lib/google/apis/trafficdirector_v3/representations.rb
Instance Attribute Summary collapse
-
#details ⇒ String
Details about the last failed update attempt.
-
#failed_configuration ⇒ Hash<String,Object>
What the component configuration would have been if the update had succeeded.
-
#last_update_attempt ⇒ String
Time of the latest failed update attempt.
-
#version_info ⇒ String
This is the version of the rejected resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UpdateFailureState
constructor
A new instance of UpdateFailureState.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UpdateFailureState
Returns a new instance of UpdateFailureState.
1707 1708 1709 |
# File 'lib/google/apis/trafficdirector_v3/classes.rb', line 1707 def initialize(**args) update!(**args) end |
Instance Attribute Details
#details ⇒ String
Details about the last failed update attempt.
Corresponds to the JSON property details
1689 1690 1691 |
# File 'lib/google/apis/trafficdirector_v3/classes.rb', line 1689 def details @details end |
#failed_configuration ⇒ Hash<String,Object>
What the component configuration would have been if the update had succeeded.
This field may not be populated by xDS clients due to storage overhead.
Corresponds to the JSON property failedConfiguration
1695 1696 1697 |
# File 'lib/google/apis/trafficdirector_v3/classes.rb', line 1695 def failed_configuration @failed_configuration end |
#last_update_attempt ⇒ String
Time of the latest failed update attempt.
Corresponds to the JSON property lastUpdateAttempt
1700 1701 1702 |
# File 'lib/google/apis/trafficdirector_v3/classes.rb', line 1700 def last_update_attempt @last_update_attempt end |
#version_info ⇒ String
This is the version of the rejected resource. [#not-implemented-hide:]
Corresponds to the JSON property versionInfo
1705 1706 1707 |
# File 'lib/google/apis/trafficdirector_v3/classes.rb', line 1705 def version_info @version_info end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1712 1713 1714 1715 1716 1717 |
# File 'lib/google/apis/trafficdirector_v3/classes.rb', line 1712 def update!(**args) @details = args[:details] if args.key?(:details) @failed_configuration = args[:failed_configuration] if args.key?(:failed_configuration) @last_update_attempt = args[:last_update_attempt] if args.key?(:last_update_attempt) @version_info = args[:version_info] if args.key?(:version_info) end |